/*******************************************************************************
* File Name: First_Digit.c  
* Version 1.60
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "First_Digit.h"


/*******************************************************************************
* Function Name: First_Digit_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void First_Digit_Write(uint8 value) 
{
    uint8 staticBits = First_Digit_DR & ~First_Digit_MASK;
    First_Digit_DR = staticBits | ((value << First_Digit_SHIFT) & First_Digit_MASK);
}


/*******************************************************************************
* Function Name: First_Digit_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void First_Digit_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(First_Digit_0, mode);
}


/*******************************************************************************
* Function Name: First_Digit_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro First_Digit_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 First_Digit_Read(void) 
{
    return (First_Digit_PS & First_Digit_MASK) >> First_Digit_SHIFT;
}


/*******************************************************************************
* Function Name: First_Digit_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 First_Digit_ReadDataReg(void) 
{
    return (First_Digit_DR & First_Digit_MASK) >> First_Digit_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(First_Digit_INTSTAT) 

    /*******************************************************************************
    * Function Name: First_Digit_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 First_Digit_ClearInterrupt(void) 
    {
        return (First_Digit_INTSTAT & First_Digit_MASK) >> First_Digit_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
