/*******************************************************************************
* File Name: Second_Digit.c  
* Version 1.60
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "Second_Digit.h"


/*******************************************************************************
* Function Name: Second_Digit_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void Second_Digit_Write(uint8 value) 
{
    uint8 staticBits = Second_Digit_DR & ~Second_Digit_MASK;
    Second_Digit_DR = staticBits | ((value << Second_Digit_SHIFT) & Second_Digit_MASK);
}


/*******************************************************************************
* Function Name: Second_Digit_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void Second_Digit_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Second_Digit_0, mode);
}


/*******************************************************************************
* Function Name: Second_Digit_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Second_Digit_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Second_Digit_Read(void) 
{
    return (Second_Digit_PS & Second_Digit_MASK) >> Second_Digit_SHIFT;
}


/*******************************************************************************
* Function Name: Second_Digit_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Second_Digit_ReadDataReg(void) 
{
    return (Second_Digit_DR & Second_Digit_MASK) >> Second_Digit_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Second_Digit_INTSTAT) 

    /*******************************************************************************
    * Function Name: Second_Digit_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Second_Digit_ClearInterrupt(void) 
    {
        return (Second_Digit_INTSTAT & Second_Digit_MASK) >> Second_Digit_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
