/*******************************************************************************
* File Name: FF_Q.c  
* Version 1.60
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "cytypes.h"
#include "FF_Q.h"


/*******************************************************************************
* Function Name: FF_Q_Write
********************************************************************************
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  void 
*  
*******************************************************************************/
void FF_Q_Write(uint8 value) 
{
    uint8 staticBits = FF_Q_DR & ~FF_Q_MASK;
    FF_Q_DR = staticBits | ((value << FF_Q_SHIFT) & FF_Q_MASK);
}


/*******************************************************************************
* Function Name: FF_Q_SetDriveMode
********************************************************************************
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to this drive mode.
*
* Return: 
*  void
*
*******************************************************************************/
void FF_Q_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(FF_Q_0, mode);
}


/*******************************************************************************
* Function Name: FF_Q_Read
********************************************************************************
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro FF_Q_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 FF_Q_Read(void) 
{
    return (FF_Q_PS & FF_Q_MASK) >> FF_Q_SHIFT;
}


/*******************************************************************************
* Function Name: FF_Q_ReadDataReg
********************************************************************************
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  void 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 FF_Q_ReadDataReg(void) 
{
    return (FF_Q_DR & FF_Q_MASK) >> FF_Q_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(FF_Q_INTSTAT) 

    /*******************************************************************************
    * Function Name: FF_Q_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  void 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 FF_Q_ClearInterrupt(void) 
    {
        return (FF_Q_INTSTAT & FF_Q_MASK) >> FF_Q_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */ 
